@@ -116,6 +116,9 @@ struct cell {
     int pauselen;
     int scellid; /* ID assigned to cell */
     int ecellid; /* ID assigned to next cell */
+      /* DVD-Video spec allows for cells to be grouped into programs nonsequentially,
+        and for the same cell to be part of more than one program. dvdauthor doesn't
+        currently support any of that, so cell IDs will always be sequential. */
     struct vm_statement *commands;
 };
 
@@ -190,7 +193,7 @@ struct pgcgroup { /* common info across a set of menus or a set of titles (<menu
     int numpgcs;
     int allentries; /* mask of entry types present */
     int numentries; /* number of entry types present */
-    struct vobgroup *vg; /* only for pstype==VTYPE_VTS, otherwise shared menugroup.vg field is used */
+    struct vobgroup *pg_vg; /* only for pstype==VTYPE_VTS, otherwise shared menugroup.mg_vg field is used */
 };
 
 struct langgroup { /* contents of a <menus> directive */
@@ -201,8 +204,8 @@ struct langgroup { /* contents of a <menus> directive */
 struct menugroup { /* contents specific to all collections of <menus> directives, either VTSM or VMGM */
     int numgroups; /* length of groups array */
     struct langgroup *groups; /* array, one entry per <menus> directive */
-    struct vobgroup *vg; /* common among all groups[i]->pg elements */
-      /* fixme: I don't think this works right with multiple <menus> ,,, </menus> sections,
+    struct vobgroup *mg_vg; /* common among all groups[i]->pg elements */
+      /* fixme: I don't think this works right with multiple <menus> ... </menus> sections,
         which the XML does allow */
 };
 
@@ -238,10 +241,10 @@ struct toc_summary {
     int numvts;
 };
 
-struct workset {
-    const struct toc_summary *titlesets;
-    const struct menugroup *menus;
-    const struct pgcgroup *titles;
+struct workset { /* overall parameters for generation of a domain (VMG or VTS) */
+    const struct toc_summary *titlesets; /* VMG only */
+    const struct menugroup *menus; /* VMG and VTS */
+    const struct pgcgroup *titles; /* VTS only */
 };
 
 /* following implemented in dvdauthor.c */
